@@ -10,7 +10,7 @@ sub new {
     my $class = shift;
     my (%params) = @_;
 
-    my $self = {};
+    my $self = { table => $params{into} };
     bless $self, $class;
 
     $self->{quoter} =
@@ -58,6 +58,9 @@ sub new {
             $sql .= join ',', @values;
             $sql .= ')';
         }
+
+        # save this for later ...
+        $self->{columns} = \@columns;
     }
     else {
         my $driver = $params{driver};
@@ -75,6 +78,8 @@ sub new {
     return $self;
 }
 
+sub table { shift->{table} }
+
 sub to_sql { shift->{sql} }
 sub to_bind { @{shift->{bind} || []} }
 
